@@ -96,7 +96,6 @@ aghui::SExpDesignUI::construct_widgets()
 
 	if ( !AGH_GBGETOBJ (GtkWindow,		wMainWindow) ||
 	     !AGH_GBGETOBJ (GtkVBox,		cMeasurements) ||
-	     !AGH_GBGETOBJ (GtkLabel,		lMsmtHint) ||
 	     !AGH_GBGETOBJ (GtkLabel,		lMsmtInfo) )
 		return -1;
 
@@ -257,11 +256,8 @@ aghui::SExpDesignUI::construct_widgets()
 
 
    // ================ 2. Simulations
-     // ------------- tvSimulations
-	if ( !(AGH_GBGETOBJ (GtkTreeView, tvSimulations)) ||
-	     !(AGH_GBGETOBJ (GtkToolButton, bSimulationsRun)) ||
-	     !(AGH_GBGETOBJ (GtkButton, bSimulationsSummary)) ||
-	     !(AGH_GBGETOBJ (GtkButton, bSimulationsClearAll)) )
+     // ------------- tvSimulations & controls
+	if ( !(AGH_GBGETOBJ (GtkTreeView, tvSimulations)) )
 		return -1;
 
 	gtk_tree_view_set_model( tvSimulations,
@@ -308,19 +304,23 @@ aghui::SExpDesignUI::construct_widgets()
 				     col = gtk_tree_view_column_new());
 	gtk_tree_view_column_set_visible( col, FALSE);
 
-	g_signal_connect( bSimulationsRun, "clicked",
-			  (GCallback)bSimulationsRun_clicked_cb,
+      // ------------ iSimulations*
+	if ( !(AGH_GBGETOBJ (GtkMenuItem, iSimulationsRunBatch)) ||
+	     !(AGH_GBGETOBJ (GtkMenuItem, iSimulationsRunClearAll)) ||
+	     !(AGH_GBGETOBJ (GtkMenuItem, iSimulationsReportGenerate)) )
+		return -1;
+
+	g_signal_connect( iSimulationsRunBatch, "activate",
+			  (GCallback)iSimulationsRunBatch_activate_cb,
 			  this);
-	g_signal_connect( bSimulationsSummary, "clicked",
-			  (GCallback)bSimulationsSummary_clicked_cb,
+	g_signal_connect( iSimulationsRunClearAll, "activate",
+			  (GCallback)iSimulationsRunClearAll_activate_cb,
 			  this);
-	g_signal_connect( bSimulationsClearAll, "clicked",
-			  (GCallback)bSimulationsClearAll_clicked_cb,
+	g_signal_connect( iSimulationsReportGenerate, "activate",
+			  (GCallback)iSimulationsReportGenerate_activate_cb,
 			  this);
 
-
-
-     // ------------- eSimulations{Session,Channel}
+      // ------------- lSimulations{Session,Channel}
 	if ( !AGH_GBGETOBJ (GtkLabel, lSimulationsSession) ||
 	     !AGH_GBGETOBJ (GtkLabel, lSimulationsChannel) )
 		return -1;
@@ -350,9 +350,6 @@ aghui::SExpDesignUI::construct_widgets()
 		  "this file was not found in that location, too bad.)", -1);
 	g_object_unref( file);
 
-	gtk_widget_set_tooltip_markup( (GtkWidget*)(lMsmtHint),
-				       tooltips[(size_t)TTip::measurements]);
-
 
       // ****************** settings
 	if ( !AGH_GBGETOBJ (GtkListStore,	mScoringPageSize) ||
@@ -421,7 +418,6 @@ aghui::SExpDesignUI::construct_widgets()
       // --------- Misc
 	if ( !AGH_GBGETOBJ (GtkSpinButton, eDAPageHeight) ||
 	     !AGH_GBGETOBJ (GtkSpinButton, eDAHypnogramHeight) ||
-	     !AGH_GBGETOBJ (GtkSpinButton, eDASpectrumWidth) ||
 	     !AGH_GBGETOBJ (GtkSpinButton, eDAEMGHeight) )
 		return -1;
 
@@ -632,6 +628,18 @@ aghui::SExpDesignUI::construct_widgets()
 	     !AGH_GBGETOBJ (GtkEntry,		eSubjectDetailsComment) )
 		return -1;
 
+      // ------------- wBatchSetup
+	if ( !AGH_GBGETOBJ (GtkDialog,		wBatchSetup) ||
+	     !AGH_GBGETOBJ (GtkEntry,		eBatchSetupSubjects) ||
+	     !AGH_GBGETOBJ (GtkEntry,		eBatchSetupSessions) ||
+	     !AGH_GBGETOBJ (GtkEntry,		eBatchSetupChannels) ||
+	     !AGH_GBGETOBJ (GtkSpinButton,	eBatchSetupRangeFrom) ||
+	     !AGH_GBGETOBJ (GtkSpinButton,	eBatchSetupRangeWidth) ||
+	     !AGH_GBGETOBJ (GtkSpinButton,	eBatchSetupRangeInc) ||
+	     !AGH_GBGETOBJ (GtkSpinButton,	eBatchSetupRangeSteps) )
+		return -1;
+
+
       // ========= sister widget
 	mExpDesignChooserList =
 		gtk_list_store_new( 1, G_TYPE_STRING);
