@@ -46,7 +46,7 @@ aghui::SScoringFacility::SChannel::draw_signal( const valarray<TFloat>& signal,
 		padded[ slice(half_pad, run + half_pad, 1) ] = signal[ slice (0, run + half_pad, 1) ];
 		::draw_signal( padded, 0, padded.size(),
 			       width, vdisp, signal_display_scale, cr,
-			       use_resample);
+			       resample_signal);
 
 	} else if ( end > n_samples() ) {  // rather ensure more thorough padding
 		valarray<TFloat> padded (run + half_pad*2);
@@ -54,14 +54,14 @@ aghui::SScoringFacility::SChannel::draw_signal( const valarray<TFloat>& signal,
 		padded[ slice(0, 1, remainder) ] = signal[ slice (start-half_pad, 1, remainder) ];
 		::draw_signal( padded, 0, padded.size(),
 			       width, vdisp, signal_display_scale, cr,
-			       use_resample);
+			       resample_signal);
 
 	} else {
 		::draw_signal( signal,
 			       start - half_pad,
 			       end + half_pad,
 			       width, vdisp, signal_display_scale, cr,
-			       use_resample);
+			       resample_signal);
 	}
 }
 
@@ -358,20 +358,18 @@ aghui::SScoringFacility::SChannel::draw_page( cairo_t* cr)
 		guint i;
 
 		if ( draw_bands ) {
-			// for ( TBand_underlying_type b = 0; b <= (TBand_underlying_type)Ch.uppermost_band; ++b ) {
-			// the type conversions exactly as appearing above drive g++ to segfault
-			// the same happens when (TBand_underlying_type) is replaced by (unsigned short)
 			for ( size_t b = sigfile::TBand::delta; b != uppermost_band; ++b ) {
 				auto& P = power_in_bands[b];
 				_p._p.CwB[SExpDesignUI::band2colour((sigfile::TBand)b)].set_source_rgba( cr, .5);
-				cairo_move_to( cr, 0.,
+				double zero = 0.5 / P.size() * _p.da_wd;
+				cairo_move_to( cr, zero,
 					       - P[0] * power_display_scale + pbot);
 				for ( i = 1; i < P.size(); ++i )
-					cairo_line_to( cr, (double)i / P.size() * _p.da_wd,
+					cairo_line_to( cr, ((double)i+0.5) / P.size() * _p.da_wd,
 						       - P[i] * power_display_scale + pbot);
 				if ( b == focused_band ) {
 					cairo_line_to( cr, _p.da_wd, pbot);
-					cairo_line_to( cr,       0., pbot);
+					cairo_line_to( cr,     zero, pbot);
 					cairo_fill( cr);
 				}
 				cairo_stroke( cr);
@@ -392,12 +390,14 @@ aghui::SScoringFacility::SChannel::draw_page( cairo_t* cr)
 			}
 		} else {
 			_p._p.CwB[SExpDesignUI::TColour::power_sf].set_source_rgba( cr, .5);
-			cairo_move_to( cr, 0, power[0]);
+			double zero = 0.5 / power.size() * _p.da_wd;
+			cairo_move_to( cr, zero,
+				       power[0]);
 			for ( i = 0; i < power.size(); ++i )
-				cairo_line_to( cr, (double)i / power.size() * _p.da_wd,
+				cairo_line_to( cr, ((double)i+.5) / power.size() * _p.da_wd,
 					       - power[i] * power_display_scale + pbot);
 			cairo_line_to( cr, _p.da_wd, pbot);
-			cairo_line_to( cr,       0., pbot);
+			cairo_line_to( cr,     zero, pbot);
 			cairo_fill( cr);
 			cairo_stroke( cr);
 
@@ -465,8 +465,8 @@ aghui::SScoringFacility::SChannel::draw_page( cairo_t* cr)
 	      // cursor
 		_p._p.CwB[SExpDesignUI::TColour::cursor].set_source_rgba( cr, .3);
 		cairo_rectangle( cr,
-				 (float) _p.cur_vpage() / _p.total_vpages() * _p.da_wd,  zeroy,
-				 ceil( 1. / _p.total_vpages() * _p.da_wd), pbot - zeroy);
+				 (double) _p.cur_vpage() / _p.total_vpages() * _p.da_wd,  zeroy,
+				 1. / _p.total_vpages() * _p.da_wd, pbot - zeroy);
 		cairo_fill( cr);
 		cairo_stroke( cr);
 	}
@@ -550,7 +550,7 @@ aghui::SScoringFacility::_draw_matrix_to_montage( cairo_t *cr, const itpp::Mat<T
 	}
 
       // waveform
-	bool our_use_resample = false;
+	bool our_resample_signal = false;
 	auto sr = channels.front().samplerate();  // ica wouldn't start if samplerates were different between any two channels
 	auto our_display_scale = channels.front().signal_display_scale;
 
@@ -573,7 +573,7 @@ aghui::SScoringFacility::_draw_matrix_to_montage( cairo_t *cr, const itpp::Mat<T
 			//padded[ slice(half_pad, run + half_pad, 1) ] = C[ slice (0, run + half_pad, 1) ];
 			::draw_signal( padded, 0, padded.size(),
 				       da_wd, our_y, our_display_scale, cr,
-				       our_use_resample);
+				       our_resample_signal);
 
 		} else if ( end > (size_t)mat.cols() ) {  // rather ensure more thorough padding
 			valarray<TFloat> padded (run + half_pad*2);
@@ -583,14 +583,14 @@ aghui::SScoringFacility::_draw_matrix_to_montage( cairo_t *cr, const itpp::Mat<T
 			//padded[ slice(0, 1, remainder) ] = C[ slice (start-half_pad, 1, remainder) ];
 			::draw_signal( padded, 0, padded.size(),
 				       da_wd, our_y, our_display_scale, cr,
-				       our_use_resample);
+				       our_resample_signal);
 
 		} else {
 			::draw_signal( mat, r,
 				       start - half_pad,
 				       end + half_pad,
 				       da_wd, our_y, our_display_scale, cr,
-				       our_use_resample);
+				       our_resample_signal);
 		}
 		our_y += gap;
 	}
