@@ -26,8 +26,8 @@ extern "C" {
 
 gboolean
 daSFMontage_configure_event_cb( GtkWidget *widget,
-					GdkEventConfigure *event,
-					gpointer userdata)
+				GdkEventConfigure *event,
+				gpointer userdata)
 {
 	 if ( event->type == GDK_CONFIGURE ) {
 		 auto& SF = *(SScoringFacility*)userdata;
@@ -123,6 +123,7 @@ daSFMontage_button_press_event_cb( GtkWidget *wid, GdkEventButton *event, gpoint
 			gtk_widget_queue_draw( wid);
 		    break;
 		case 3:
+			Ch->update_power_check_menu_items();
 			gtk_menu_popup( SF.mSFPower,
 					NULL, NULL, NULL, NULL, 3, event->time);
 		    break;
@@ -143,11 +144,8 @@ daSFMontage_button_press_event_cb( GtkWidget *wid, GdkEventButton *event, gpoint
 		switch ( event->button ) {
 		case 2:
 			if ( event->state & GDK_CONTROL_MASK )
-				for_each( SF.channels.begin(), SF.channels.end(),
-					  [&SF] ( SScoringFacility::SChannel& H)
-					  {
-						  H.signal_display_scale = SF.sane_signal_display_scale;
-					  });
+				for ( auto H : SF.channels )
+					H.signal_display_scale = SF.sane_signal_display_scale;
 			else
 				Ch->signal_display_scale = SF.sane_signal_display_scale;
 			gtk_widget_queue_draw( wid);
@@ -327,7 +325,7 @@ daSFMontage_scroll_event_cb( GtkWidget *wid, GdkEventScroll *event, gpointer use
 					if ( Ch->from > 0 ) {
 						Ch->from = Ch->from - .5;
 						Ch->upto = Ch->upto - .5;
-						Ch->get_power();
+						Ch->get_power( false);
 						gtk_widget_queue_draw( wid);
 					}
 			    break;
@@ -341,7 +339,7 @@ daSFMontage_scroll_event_cb( GtkWidget *wid, GdkEventScroll *event, gpointer use
 					if ( Ch->upto < 18. ) {
 						Ch->from = Ch->from + .5;
 						Ch->upto = Ch->upto + .5;
-						Ch->get_power();
+						Ch->get_power( false);
 						gtk_widget_queue_draw( wid);
 					}
 			    break;
@@ -435,10 +433,11 @@ void
 iSFPageUseResample_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
-	SF.using_channel->use_resample = (bool)gtk_check_menu_item_get_active( checkmenuitem);
+	SF.using_channel->resample_signal = (bool)gtk_check_menu_item_get_active( checkmenuitem);
 	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
 }
 
+
 void
 iSFPageDrawZeroline_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
 {
@@ -529,8 +528,8 @@ iSFPageClearArtifacts_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 	SF.using_channel->get_signal_filtered();
 
 	if ( SF.using_channel->type == sigfile::SChannel::TType::eeg ) {
-		SF.using_channel->get_power();
-		SF.using_channel->get_power_in_bands();
+		SF.using_channel->get_power( false);
+		SF.using_channel->get_power_in_bands( false);
 	}
 
 	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
@@ -561,11 +560,11 @@ iSFPageExportSignal_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
 	auto& r = SF.using_channel->crecording;
-	string fname_base = r.fname_base();
-	snprintf_buf( "%s-orig.tsv", fname_base.c_str());
-	r.F().export_original( SF.using_channel->name, __buf__);
+	string fname_base = r.F().filename();
 	snprintf_buf( "%s-filt.tsv", fname_base.c_str());
 	r.F().export_filtered( SF.using_channel->name, __buf__);
+	snprintf_buf( "%s-orig.tsv", fname_base.c_str());
+	r.F().export_original( SF.using_channel->h(), __buf__);
 	snprintf_buf( "Wrote \"%s-{filt,orig}.tsv\"",
 		      fname_base.c_str());
 	gtk_statusbar_pop( SF.sbSF, SF._p.sbContextIdGeneral);
@@ -709,6 +708,7 @@ iSFPageSelectionAnnotate_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 
 
 // power
+
 void
 iSFPowerExportRange_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 {
@@ -738,6 +738,24 @@ iSFPowerExportAll_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 	SF._p.buf_on_status_bar();
 }
 
+void
+iSFPowerSmooth_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
+{
+	auto& SF = *(SScoringFacility*)userdata;
+	SF.using_channel->resample_power = (bool)gtk_check_menu_item_get_active( checkmenuitem);
+	SF.using_channel->get_power(false);
+	SF.using_channel->get_power_in_bands(false);
+	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
+}
+
+void
+iSFPowerDrawBands_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
+{
+	auto& SF = *(SScoringFacility*)userdata;
+	SF.using_channel->draw_bands = (bool)gtk_check_menu_item_get_active( checkmenuitem);
+	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
+}
+
 void
 iSFPowerUseThisScale_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 {
